Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Command ¶
type Command struct {
// contains filtered or unexported fields
}
Command represents a single command.
func NewCommand ¶
NewCommand returns a new command with the specified name, flags and runner. The runner could be nil in order to use the command as the root of other subcommands.
func (*Command) AddCommand ¶
AddCommand adds a subcommand to the supported subcommands.
Click to show internal directories.
Click to hide internal directories.